
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%David Escobar Sanabria
%Aerospace Engineering and Mechanics 
%University of Minnesota, Twin Cities
%descobar@aem.umn.edu
%Base script to plot flight and simulation data
%
%  This script synchronizes the simulation and flight data commands to plot 
%  doublet sequences from software in the loop simulation and flight test.
%  Initial and final times of flight data to be plotted are already selected 
%  to match with the algorithms. 
%  
%  This script assumes:
%  1) There exist the following files:
%       ../SIL_Sim/Verification/simDataLqr
%       ../SIL_Sim/Verification/simDataBaseline
%   These files are obtained after running the software in the loop simulation
%   with baseline and lqr controllers under the same flight conditions.
%   test. These conditions are listed as follows:
%       - Period of the doublet signal: 6 sec.
%       - Amplitud of pitch reference signal : +/- 5 deg
%       - Amplitud of roll reference signal : +/- 20 deg
%  2) The flight test data is located in the folder: ../../FlightData/
%  
%  Follow the instructions in comments to select the flight test data and
%  generate the plots
 
%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% 
close all;
clc
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%% LIST OF DATA FILES: %%%%%%%%%%%%%%%%%%%%%%%%%
F2010_09_16_FLIGHT_01_BASELINE=0;
F2010_09_16_FLIGHT_03_BASELINE=1;
F2010_09_16_FLIGHT_10_BASELINE=2;
F2010_10_01_FLIGHT_04_BASELINE=3;
F2010_10_01_FLIGHT_05_BASELINE=4;
F2010_10_08_FLIGHT_07_LQR=5;
F2010_10_08_FLIGHT_21_LQR=6;

% Choose one of the above data sets to be plotted:
flight_data = 3;

%%
%%%%%%% The following sections do not need to be modified %%%%%%%%%%%%%%%%%
% Setting options for fligth data selected:

% Data types:
DATA_TYPE_OLD = 1;
DATA_TYPE_NEW = 2;

% Control types
CONTROL_TYPE_BASELINE=1;
CONTROL_TYPE_LQR=2;

data_type = 0;
control_type=2;

switch (flight_data)
    case F2010_09_16_FLIGHT_01_BASELINE
        control_type=CONTROL_TYPE_BASELINE;
        data_type= DATA_TYPE_OLD;
        load ../../FlightData/System_Development/loki_flight01_baseline;
        initSample = 27000;
        finalSample=60000;
        
    case F2010_09_16_FLIGHT_03_BASELINE
        control_type=CONTROL_TYPE_BASELINE;
        data_type= DATA_TYPE_OLD;
        load ../../FlightData/System_Development/loki_flight03_baseline;
        initSample = 11000;
        finalSample=30000;
    
    case F2010_09_16_FLIGHT_10_BASELINE
        control_type=CONTROL_TYPE_BASELINE;
        data_type= DATA_TYPE_OLD;
        load ../../FlightData/Control_Laws/odin_flight10_baseline;
        initSample = 5000;
        finalSample=46000;
    
    case F2010_10_01_FLIGHT_04_BASELINE
        control_type=CONTROL_TYPE_BASELINE;
        data_type= DATA_TYPE_NEW;
        load ../../FlightData/System_Development/loki_flight04_baseline;
        initSample = 25000;
        finalSample=35000;
        
    case F2010_10_01_FLIGHT_05_BASELINE
        control_type=CONTROL_TYPE_BASELINE;
        data_type= DATA_TYPE_NEW;
        load ../../FlightData/System_Development/loki_flight05_baseline;
        initSample = 6000;
        finalSample=14000;
        
    case F2010_10_08_FLIGHT_07_LQR
        control_type=CONTROL_TYPE_LQR;
        data_type= DATA_TYPE_NEW;
        load ../../FlightData/Control_Laws/loki_flight07_lqr;
        initSample = 15000;
        finalSample=30500;
        
    case F2010_10_08_FLIGHT_21_LQR
        control_type=CONTROL_TYPE_LQR;
        data_type= DATA_TYPE_NEW;
        load ../../FlightData/Control_Laws/odin_flight21_lqr;
        initSample = 11000;
        finalSample=19000;

end
    
if(control_type==CONTROL_TYPE_LQR)
    load ../SIL_Sim/Verification/simDataLqr
else
    load ../SIL_Sim/Verification/simDataBaseline
end

% Simulation - sample time
Ts= 0.02;
%% Plots: 
%Matches and plots: flight and simulation data:
plotMatching(flight_data, simData,initSample,finalSample, Ts, data_type);
