/******************************************************************************
 *global definitions used in the avionics program
 *
 * University of Minnesota 
 * Aerospace Engineering and Mechanics 
 * Copyright 2011 Regents of the University of Minnesota. All rights reserved.
 *
 * $Id: globaldefs.h 332 2011-04-14 18:43:14Z murch $
 ******************************************************************************/
#ifndef GLOBALDEFS_H_
#define GLOBALDEFS_H_

#ifndef TRUE
#define TRUE				1
#endif
#ifndef FALSE
#define FALSE		   		0
#endif

#define	byte				unsigned char
#define word				unsigned short
#define NSECS_PER_SEC		1000000000
#define	mymin(arg1,arg2) 	(arg1<=arg2 ? arg1:arg2)
#define	mymax(arg1,arg2)	(arg1>=arg2 ? arg1:arg2)

#define PWM_COUNTS_RANGE	2180	// these values correspond to 1.1ms to 1.9ms usable range
#define PWM_1ms_COUNTS		2997
#define NUM_THREADS	  		6

// ****** Unit conversions and constant definitions: ***************************
#define D2R			0.017453292519943  // rad
#define R2D			57.295779513082323 // deg
#define PSI_TO_KPA  6.89475729  // KPa
#define	g			9.814		// m/sec^2
#define g2      	19.62   	// 2*g
#define pi      	3.141592    // pi
#define pi2     	6.283184	// pi*2
// *****************************************************************************

// ****** AIR DATA CONSTANTS ***************************************************
#define AIR_DATA_P0  101.3251600806359 //[KPa], standard pressure
#define AIR_DATA_K1  44330.739888      //[m]
#define AIR_DATA_K2  0.1903  	 	   //[no units]
#define AIR_DATA_K3  760.4262731       //[ m/s ]
#define AIR_DATA_K4  0.285714285714286 //[no units]
// *****************************************************************************

/* USER CONFIGURATION */

#define GPIO_ENABLED
#define DATALOG_ENABLE
#define DATALOG_RAMFS   // or DATALOG_FLASH
#define DATALOG_LSB		// Log data in little endian byte order
//#define MNAV		// if Crossbow Micronav IMU is used
//#define MB_ADS      // if MicroBotics Air Data System is used. Currently must be used with "MNAV".

// select GPS chipset in use
#define SIRF
//define CRESCENT


enum   errdefs			{ got_invalid, checksum_err, gps_nolock, data_valid, mag_CalibrationBad };
enum   modedefs 		{ altitude_hold,airspeed_hold,waypoint_nav };
enum   OFPMODES			{ sleepmode, prelaunch, standby, launchmission, returnhome, terminate };




double ias_ref=8.0, alt_ref=100.0;   // initial values
double airdata_bias[2];				// bias estimates of airdata sensors, computed before launch
short  whichmode[3]={FALSE,};
int sPort0, sPort1;					// RS232 serial ports
int sPort2, sPort3;					// TTL level serial ports
char msg[53]={'U','U','M',0,};		// TX buffer for status/diagnostic messages to dnlink (system message packet)
enum OFPMODES ofpMode = launchmission;		//init value
char buf[20*1024*1024];			// for TFTP file transfer
int  fileHandle1;				// datalogging file handle



struct imu {
	double p,q,r;		/* angular velocities    */
	double ax,ay,az;		/* acceleration          */
	double hx,hy,hz;             /* magnetic field     	 */
	double ias,h;                /* indicated airspeed/altitude (AGL) */
	double Ps,Pd;                /* static/differential pressure */

	double phi,the,psi;          /* attitudes             */	// 1-2-3
	float  T;		/* temperature */
	float  Vs;		/* supply voltage */
	double adc;
	//short  err_type;		/* error type		 */
	enum errdefs err_type;
	double time;
};

#ifndef SIL_MODE_

struct 		mallinfo info;		// memory usage status data struct

struct threadInfo {
	char name[8];
	unsigned short frequency;
	unsigned int priority;
	int jitter_nsec;
};

struct flightdat {
	float p,q,r;		/* angular velocities    */
	float ax,ay,az;		/* acceleration          */
	float hx,hy,hz;             /* magnetic field     	 */
	float h,ias;                /* altitude (AGL)/indicated airspeed */
	float phi,the,psi;          /* attitudes             */	// 1-2-3
	float lat,lon,alt;
	float pitch_ref, roll_ref;
	float de, da, dr, dthr;
	enum errdefs gps_status, imu_status;
	short mode;
	float time;
};

struct flightdat2 {
	float p,q,r;		/* angular velocities    */
	float ax,ay,az;		/* acceleration          */
	float hx,hy,hz;             /* magnetic field     	 */
	float h,ias;                /* altitude (AGL)/indicated airspeed */
	float Ps,Pd;				/* static/differential pressures */
	float phi,the,psi;          /* attitudes             */	// 1-2-3
	float lat,lon,alt;
	float vn,ve,vd;
	float navlat,navlon,navalt;
	float navvn,navve,navvd;
	float pitch_ref, roll_ref;
	float de, da_l, da_r, df_l, df_r, dr, dthr;
	enum  errdefs gps_status, imu_status;
	short mode;
	int   threadJitter[6];	/* nanoseconds */
	float time;
};

struct gps {
	double lat,lon,alt;          /* gps position   (LLA)       */
	double ve,vn,vd;             /* gps velocity   (LLA)       */
	double Xe,Ye,Ze;			 /* m (ECEF) */
	double Ue,Ve,We;			 /* m/s (ECEF) */
	uint16_t GPS_week;
	uint32_t GPS_TOW;			 /* seconds */
	uint8_t UTC_year, UTC_month, UTC_day, UTC_hour, UTC_min;
	float UTC_secs;
	uint16_t SatVisible;
	float HDOP;
	enum errdefs err_type;
	double time;
};

#endif


#ifdef SIL_MODE_

#define		cdT	        	0.04   	     // 25 Hz

struct gps {
   double lat,lon,alt;          /* gps position          */
   double ve,vn,vd;             /* gps velocity          */
   word   ITOW;
   short  err_type;             /* error type            */
   double time;
};
#endif

struct control_data {

	double da,de, dthr, dr;

};



struct nav {
	double lat,lon,alt;
	double ve,vn,vd;
	enum errdefs err_type;
	double time;
};

/*
struct gps {
	double lat,lon,alt;
	double ve,vn,vd;
	double   ITOW;
	enum errdefs err_type;
	double time;
};
*/

/*
struct servo {
	unsigned short chn[8];
	unsigned char status;
};
*/

#ifndef SIL_MODE_

struct  imu   imupacket;
struct  gps   gpspacket;
struct  nav   navpacket;
struct  control_data controlpacket;
struct  flightdat2 fltdatpacket;
struct  threadInfo	threadstat[NUM_THREADS];

//mutex and conditional variables
pthread_mutex_t	mutex_imu;
pthread_mutex_t	mutex_gps;
pthread_mutex_t mutex_nav;
pthread_mutex_t mutex_fdat;
pthread_mutex_t mutex_sPort0;
pthread_cond_t  trigger_ahrs, trigger_sensordaq, trigger_claw \
				, trigger_navigation, trigger_downlink, trigger_datalogger;

/********************************************************************
 ** CPU load measurement parameters
 ********************************************************************/
cyg_uint32 cpuCalibrationData, last100ms, last1s, last10s;
cyg_cpuload_t cpuload;
cyg_handle_t loadhandle;

#endif


#endif	/* GLOBALDEFS_H_ */
