/******************************************************************************
 * FILE: airDataSys.c
 *
 * DESCRIPTION:
 * C class header: Microbotics: SPA20422 AIR DATA SYSTEM
 *
 * CREATED: 09-28-10: David Escobar Sanabria
 * University of Minnesota 
 * Aerospace Engineering and Mechanics 
 * Copyright 2011 Regents of the University of Minnesota. All rights reserved.
 *
 * $Id: airDataSys.h 332 2011-04-14 18:43:14Z murch $
 ******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <termios.h>
#include <math.h>
#include <pthread.h>
#include <sched.h>
#include <cyg/posix/pthread.h>
#include <cyg/kernel/kapi.h>
#include <cyg/posix/time.h>
#include <cyg/posix/signal.h>
#include <cyg/cpuload/cpuload.h>
#include <cyg/gpt/mpc5xxx_gpt.h>
#include <cyg/io/mpc5xxx_gpio.h>
#include <cyg/io/i2c_mpc5xxx.h>


#include "../../utils/serial_mpc5200.c"


/// Frame size for microbotics pressuere sensor. 
#define AIR_DATA_SYS_FRAME_SIZE 28  /// Size of the sensor frame

#define MAX_BYTE_ATTEMPS 5000 /// Mmaximum number of byte readings. If it is higher, 
				/// means that there is no data comming
				
#define MAX_FRAME_ATTEMPS 10 /// Mmaximum number of frame readings. If it is higher, 
				 /// means that the frame is not matching with the sensor protovol
				 

/// Definition of errors:

#define ADS_ERROR_NO_DATA  -1
#define ADS_ERROR_PROTOCOL  -2
#define ADS_ERROR_CHECKSUM  -3

/// Globals

int airDataSysPortID;

int end = 0;
/// Counts the incomming bytes of the sensor data frame
uint8_t counterFrame=0;
uint16_t counterByteAttemps= 0;
uint8_t counterFrameAttemps= 0;
/// Saves the incomming byte
uint8_t byteIn[1];
/// Saves the bytes in an array
uint8_t bufferIn[AIR_DATA_SYS_FRAME_SIZE+2];
/// Values of the checksum variables
uint16_t cs0=0, cs1=0;
/// lenght of a serial port reading
int len=0;

/// Information for serial buffer 
cyg_serial_buf_info_t ads_buff_info;
cyg_io_handle_t ads_console_handle;
unsigned int adsBytesInBuffer,ads_buff_len;  

/// Initialization of pressure sensor suite
int airDataSysStart(char* serial_port,int baudrate);

/// Initialization of serial port
int initSerial(char *portname, int baudrate);

/// Reads sensor protocol
int getAirDataSysFrame(uint8_t *dataPacket );

int getADSStatus(uint8_t *dataFrame);

int getADSUTime(uint8_t *dataFrame);

// Absolute pressure [KPa]
double getADSAbsolutePressure(uint8_t *dataFrame);

// Effective Sea-Level Pressure [KPa]
double getADSEffectiveSeaLevelPressure(uint8_t *dataFrame);

// Altitude [m]
double getADSAltitude(uint8_t *dataFrame);

// Internal temperature [ C ]
double getADSInternalTemperature(uint8_t *dataFrame);

// External temperature [ C ]
double getADSExternalTemperature(uint8_t *dataFrame);

int getADSDryAirDensity(uint8_t *dataFrame);

double getADSDifferentialPressure(uint8_t *dataFrame);

double getADSAirSpeed(uint8_t *dataFrame);

void updateADSAltitude(int altitude);

void updateADSSeaPressure(int P0);

void resetADSDifferentialPressure();

void setADSFrameRate(int n50ms);

void setADSBinary();



